@@ -1,5 +1,5 @@
 ##############################################################################
-# Copyright (c) 2009,2010 Hajime Nakagami<nakagami@gmail.com>
+# Copyright (c) 2009-2011 Hajime Nakagami<nakagami@gmail.com>
 # All rights reserved.
 # Licensed under the New BSD License
 # (http://www.freebsd.org/copyright/freebsd-license.html)
@@ -22,7 +22,7 @@ def bs(byte_array):
     return ''.join([chr(c) for c in byte_array])
 
 DEBUG = False
-__version__ = '0.3.3'
+__version__ = '0.3.4'
 apilevel = '2.0'
 threadsafety = 1
 paramstyle = 'qmark'
@@ -56,6 +56,66 @@ isc_tpb_restart_requests = 19
 isc_tpb_no_auto_undo = 20
 isc_tpb_lock_timeout = 21
 
+
+# Service Parameter Block parameter
+isc_spb_version1 = 1
+isc_spb_current_version = 2
+isc_spb_version = isc_spb_current_version
+isc_spb_user_name = 28              # isc_dpb_user_name
+isc_spb_sys_user_name = 19          # isc_dpb_sys_user_name
+isc_spb_sys_user_name_enc = 31      # isc_dpb_sys_user_name_enc
+isc_spb_password = 29               # isc_dpb_password
+isc_spb_password_enc = 30           # isc_dpb_password_enc
+isc_spb_command_line = 105
+isc_spb_dbname = 106
+isc_spb_verbose = 107
+isc_spb_options = 108
+isc_spb_address_path = 109
+isc_spb_process_id = 110
+isc_spb_trusted_auth = 111
+isc_spb_process_name = 112
+isc_spb_trusted_role = 113
+isc_spb_connect_timeout = 57        # isc_dpb_connect_timeout
+isc_spb_dummy_packet_interval = 58  # isc_dpb_dummy_packet_interval
+isc_spb_sql_role_name = 60          # isc_dpb_sql_role_name
+# backup
+isc_spb_bkp_file = 5
+# restore
+isc_spb_res_buffers = 9
+isc_spb_res_page_size = 10
+# trace
+isc_spb_trc_id = 1
+isc_spb_trc_name = 2
+isc_spb_trc_cfg = 3
+
+
+# Service Action Items
+isc_action_svc_backup = 1
+isc_action_svc_restore = 2
+isc_action_svc_repair = 3
+isc_action_svc_add_user = 4
+isc_action_svc_delete_user = 5
+isc_action_svc_modify_user = 6
+isc_action_svc_display_user = 7
+isc_action_svc_properties = 8
+isc_action_svc_add_license = 9
+isc_action_svc_remove_license = 10
+isc_action_svc_db_stats = 11
+isc_action_svc_get_ib_log = 12
+isc_action_svc_get_fb_log = 12
+isc_action_svc_nbak = 20
+isc_action_svc_nrest = 21
+isc_action_svc_trace_start = 22
+isc_action_svc_trace_stop = 23
+isc_action_svc_trace_suspend = 24
+isc_action_svc_trace_resume = 25
+isc_action_svc_trace_list = 26
+isc_action_svc_set_mapping = 27
+isc_action_svc_drop_mapping = 28
+isc_action_svc_display_user_adm = 29
+isc_action_svc_last = 30
+
+
 transaction_parameter_block = [
     # ISOLATION_LEVEL_READ_UNCOMMITTED
     bs([isc_tpb_version3, isc_tpb_write, isc_tpb_wait, isc_tpb_read_committed, isc_tpb_rec_version]),
@@ -356,6 +416,8 @@ class XSQLVAR:
             yyyy, mm, dd = self._parse_date(raw_value[:4])
             h, m, s, ms = self._parse_time(raw_value[4:])
             return datetime.datetime(yyyy, mm, dd, h, m, s, ms)
+        elif self.sqltype == SQL_TYPE_FLOAT:
+            return struct.unpack('!f', raw_value)[0]
         elif self.sqltype == SQL_TYPE_DOUBLE:
             return struct.unpack('!d', raw_value)[0]
         else:
@@ -1165,13 +1227,13 @@ class service_mgr(BaseConnect):
         self.db_handle = h
 
     def backup_database(self, backup_filename, f=None):
-        spb = bs([1])
+        spb = bs([isc_action_svc_backup])
         s = self.str_to_bytes(self.filename)
-        spb += bs([0x6a]) + int_to_bytes(len(s), 2) + s
+        spb += bs([isc_spb_dbname]) + int_to_bytes(len(s), 2) + s
         s = self.str_to_bytes(backup_filename)
-        spb += bs([0x05]) + int_to_bytes(len(s), 2) + s
+        spb += bs([isc_spb_bkp_file]) + int_to_bytes(len(s), 2) + s
         if f:
-            spb += bs([0x6b])
+            spb += bs([isc_spb_verbose])
         self._op_service_start(spb)
         (h, oid, buf) = self._op_response()
         self.svc_handle = h
@@ -1184,14 +1246,14 @@ class service_mgr(BaseConnect):
             (f if f else sys.stdout).write(self.bytes_to_str(buf[3:3+ln]))
 
     def restore_database(self, restore_filename, f=None):
-        spb = bs([2])
+        spb = bs([isc_action_svc_restore])
         s = self.str_to_bytes(restore_filename)
-        spb += bs([0x05]) + int_to_bytes(len(s), 2) + s
+        spb += bs([isc_spb_bkp_file]) + int_to_bytes(len(s), 2) + s
         s = self.str_to_bytes(self.filename)
-        spb += bs([0x6a]) + int_to_bytes(len(s), 2) + s
+        spb += bs([isc_spb_dbname]) + int_to_bytes(len(s), 2) + s
         if f:
-            spb += bs([0x6b])
-        spb += bs([0x09,0x00,0x08,0x00,0x00,0x0a,0x00,0x10,0x00,0x00,0x6c,0x00,0x30,0x00,0x00])
+            spb += bs([isc_spb_verbose])
+        spb += bs([isc_spb_res_buffers,0x00,0x08,0x00,0x00,isc_spb_res_page_size,0x00,0x10,0x00,0x00,isc_spb_options,0x00,0x30,0x00,0x00])
         self._op_service_start(spb)
         (h, oid, buf) = self._op_response()
         self.svc_handle = h
